@@ -2,7 +2,12 @@
 import traceback
 import sys
 from dogtail.tree import root
-from qecore.utility import QE_DEVELOPMENT
+from qecore.utility import QE_DEVELOPMENT, Tuple
+
+__author__ = """
+Filip Pokryvka <fpokryvk@redhat.com>,
+Michal Odehnal <modehnal@redhat.com>
+"""
 
 if QE_DEVELOPMENT:
     try:
@@ -12,8 +17,7 @@ if QE_DEVELOPMENT:
 
 
 class GetNode:
-    def __init__(self, context, name, role_name, description,
-                 m_btn, attr, a11y_root_name, retry, expect_positive):
+    def __init__(self, context, **kwargs):
         """
         Initiate GetNode instance.
         Workhorse for most of the :py:mod:`common_steps`.
@@ -38,8 +42,24 @@ class GetNode:
         :param attr: Node identification: attribute.
             The most used options are: ["showing", "visible", "checked", "focused", "sensitive"]
 
-        :type intance_root_name: str
-        :param intance_root_name: Application name.
+        :type size_low: string
+        :param size_low: minimum node size
+            Should be formated "width,height", where width and height are integers
+
+        :type size_high: string
+        :param size_high: maximum node size
+            Should be formated "width,height", where width and height are integers
+
+        :type position_low: string
+        :param position_low: minimum distance from topleft corner
+            Should be formated "x,y", where x and y are integers
+
+        :type position_high: string
+        :param position_high: maximum distance from topleft corner
+            Should be formated "x,y", where x and y are integers
+
+        :type a11y_root_name: str
+        :param a11y_root_name: Application name.
             Application name to be found in context.<app_name> or in accessibility tree.
             If search of accessibility tree fails the context object will be examined
             for Application instance.
@@ -58,6 +78,25 @@ class GetNode:
             This class serves only for the purposes of the :py:mod:`common_steps` implementation.
         """
 
+        name = kwargs.get("name", "None")
+        role_name = kwargs.get("role_name", "None")
+        m_btn = kwargs.get("m_btn", None)
+        attr = kwargs.get("attr", None)
+        description = kwargs.get("description", None)
+
+        def string_to_int_tuple(arg):
+            return Tuple((int(x) for x in arg.split(",")))
+
+        self.size_low = string_to_int_tuple(kwargs.get("size_low", "1,0"))
+        self.size_high = string_to_int_tuple(kwargs.get("size_high", "1000000,1000000"))
+        self.position_low = string_to_int_tuple(kwargs.get("position_low", "0,0"))
+        self.position_high = string_to_int_tuple(kwargs.get("position_high", "1000000,1000000"))
+
+        a11y_root_name = kwargs.get("a11y_root_name", None)
+        retry = kwargs.get("retry", False)
+        expect_positive = kwargs.get("expect_positive", False)
+
+
         a11y_roots = {x.name: x for x in root.applications()}
 
         if a11y_root_name in a11y_roots:
@@ -114,12 +153,14 @@ class GetNode:
     def __enter__(self):
         try:
             found_node = self.root.findChild(lambda x: \
-                ((not self.name is not None) or self.name in repr(x.name)) and \
-                ((not self.role_name is not None) or self.role_name == x.roleName) and \
-                ((not self.description is not None) or self.description in x.description) and \
-                ((not self.attr is not None) or getattr(x, self.attr)) and \
-                x.position[0] >= 0 and \
-                x.size[0] > 0, \
+                ((self.name is None) or self.name in repr(x.name)) and \
+                ((self.role_name is None) or self.role_name == x.roleName) and \
+                ((self.description is None) or self.description in x.description) and \
+                ((self.attr is None) or getattr(x, self.attr)) and \
+                Tuple(x.position) >= self.position_low and \
+                Tuple(x.position) <= self.position_high and \
+                Tuple(x.size) >= self.size_low and \
+                Tuple(x.size) <= self.size_high, \
                 retry=self.retry)
         except Exception as error:
             if self.expect_positive:
