@@ -2,6 +2,7 @@
 import os
 import re
 import base64
+import traceback
 from time import sleep
 from subprocess import Popen
 from dogtail.tree import root
@@ -35,6 +36,8 @@ class TestSandbox:
         self.background_image_revert = False
         self.background_image_location = None
 
+        self.enable_animations = None
+
         self.logging_start = None
         self.screenshot_run_result = None
 
@@ -61,6 +64,9 @@ class TestSandbox:
 
         self.production = True
 
+        self.after_scenario_hooks = []
+        self.reverse_after_scenario_hooks = False
+
         self.applications = []
         self.default_application = None
         self.retrieve_session_data()
@@ -68,8 +74,6 @@ class TestSandbox:
 
         self.shell = root.application("gnome-shell")
 
-        self.preserve_old_api()
-
 
     def before_scenario(self, context, scenario):
         """
@@ -87,7 +91,9 @@ class TestSandbox:
 
         self.failed_test = False
 
-        self.current_scenario = scenario.tags[0]
+        self.set_animations()
+
+        self.current_scenario = scenario.tags[-1]
         self.set_log_start_time()
         self.overview_action("hide")
         self.set_typing_delay(0.2)
@@ -155,6 +161,26 @@ class TestSandbox:
         if self.attach_faf and (self.failed_test or self.attach_faf_on_pass):
             self.attach_abrt_link_to_report(context)
 
+        hook_error = False
+
+        if self.reverse_after_scenario_hooks:
+            self.after_scenario_hooks.reverse()
+
+        for callback, args, kwargs in self.after_scenario_hooks:
+            try:
+                callback(*args, **kwargs)
+            except Exception as error:
+                hook_error = True
+                error_trace = traceback.format_exc()
+                context.embed("text/plain",
+                              f"Hook Error: {error}\n{error_trace}",
+                              caption="Hook Error")
+
+        self.after_scenario_hooks = []
+
+        if hook_error:
+            raise Exception("Exception during after_scenario hook")
+
 
     def start_recording(self):
         """
@@ -392,6 +418,60 @@ class TestSandbox:
         context.embed = embed_data
 
 
+    def add_after_scenario_hook(self, callback, *args, **kwargs):
+        """
+        Creates hook from callback function and its arguments.
+        Hook will be called during :func:`sandbox.after_scenario`.
+
+        :type callback: <function>
+        :param callback: function to be called
+
+        .. note::
+            :func:`sandbox.after_scenario` should be called in :func:`after_scenario`,
+            otherwise this function has no effect.
+
+        .. note::
+            Hooks are called in the order they were added. To reverse the order of execution
+            set `sandbox.reverse_after_scenario_hooks` to `True` (default `False`).
+
+        **Examples**::
+
+            # already defined function
+            def something():
+                ...
+
+            sandbox.add_after_scenario_hook(something)
+
+            # call command
+            sandbox.add_after_scenario_hook(subprocess.call, "command to be called", shell=True)
+
+            # embed data - if you want them embeded in the last step
+            sandbox.add_after_scenario_hook(context.embed, "text/plain", data, caption="DATA")
+
+            # embed data computed later (read log file)
+            sandbox.add_after_scenario_hook(lambda context: context.embed("text/plain", open(log_file).read(), caption="LOG"), context)
+
+        """
+
+        self.after_scenario_hooks += [(callback, args, kwargs)]
+
+
+    def set_animations(self):
+        """
+        Set animations via gsettings command.
+        Default value is None so the settings is not set unless user specifies otherwise.
+        """
+
+        if self.enable_animations is not None:
+            run(" ".join((
+                "gsettings",
+                "set",
+                "org.gnome.desktop.interface",
+                "enable-animations",
+                "true" if self.enable_animations else "false"
+            )))
+
+
     def set_log_start_time(self):
         """
         Save time.
@@ -566,8 +646,7 @@ class TestSandbox:
             log.info("copy_data_folder(self)")
 
         if os.path.isdir("data/"):
-            for single_file in os.listdir("data/"):
-                run(f"cp data/{single_file} /tmp/{single_file}")
+            run(f"rsync -r data/ /tmp/")
 
 
     def detect_keyring(self):
@@ -952,26 +1031,82 @@ class TestSandbox:
             assert False, "Unknown option"
 
 
-    # Preserving older api as we have tests with those function calls
-    def preserve_old_api(self):
-        """
-        Preserving old api as the new names of functions and attributes are snake_case complient.
+    #Using properties to preserve old api of attributes
+    @property
+    def recordVideo(self):
+        return self.record_video
+    @recordVideo.setter
+    def recordVideo(self, value):
+        self.record_video = value
 
-        .. note::
 
-            Do **NOT** call this by yourself. This method is called by :func:`__init__`.
-        """
+    @property
+    def recordVideoPid(self):
+        return self.record_video_pid
+    @recordVideoPid.setter
+    def recordVideoPid(self, value):
+        self.record_video_pid = value
 
-        if self.logging:
-            log.info(f"preserve_old_api(self)")
 
-        self.recordVideo = self.record_video
-        self.recordVideoPid = self.record_video_pid
-        self.attachVideo = self.attach_video
-        self.attachVideoOnPass = self.attach_video_on_pass
-        self.attachJournal = self.attach_journal
-        self.attachJournalOnPass = self.attach_journal_on_pass
-        self.attachScreenshot = self.attach_screenshot
-        self.failedTest = self.failed_test
-        self.attachFAF = self.attach_faf
-        self.attachFAFOnPass = self.attach_faf_on_pass
+    @property
+    def attachVideo(self):
+        return self.attach_video
+    @attachVideo.setter
+    def attachVideo(self, value):
+        self.attach_video = value
+
+
+    @property
+    def attachVideoOnPass(self):
+        return self.attach_video_on_pass
+    @attachVideoOnPass.setter
+    def attachVideoOnPass(self, value):
+        self.attach_video_on_pass = value
+
+
+    @property
+    def attachJournal(self):
+        return self.attach_journal
+    @attachJournal.setter
+    def attachJournal(self, value):
+        self.attach_journal = value
+
+
+    @property
+    def attachJournalOnPass(self):
+        return self.attach_journal_on_pass
+    @attachJournalOnPass.setter
+    def attachJournalOnPass(self, value):
+        self.attach_journal_on_pass = value
+
+
+    @property
+    def attachScreenshot(self):
+        return self.attach_screenshot
+    @attachScreenshot.setter
+    def attachScreenshot(self, value):
+        self.attach_screenshot = value
+
+
+    @property
+    def failedTest(self):
+        return self.failed_test
+    @failedTest.setter
+    def failedTest(self, value):
+        self.failed_test = value
+
+
+    @property
+    def attachFAF(self):
+        return self.attach_faf
+    @attachFAF.setter
+    def attachFAF(self, value):
+        self.attach_faf = value
+
+
+    @property
+    def attachFAFOnPass(self):
+        return self.attach_faf_on_pass
+    @attachFAFOnPass.setter
+    def attachFAFOnPass(self, value):
+        self.attach_faf_on_pass = value
